/************************************************************************/
/*																		*/
/*	BT2.cpp		--		Definition for BT2 library 	    				*/
/*																		*/
/************************************************************************/
/*	Author:		Eric Marsh												*/
/*	Copyright 2016, Digilent Inc.										*/
/************************************************************************/
/*  File Description:													*/
/*		This file defines functions for the PmodBT2						*/
/*																		*/
/************************************************************************/
/*  Revision History:													*/
/*																		*/
/*	07/13/2016(EricM): created											*/
/*																		*/
/************************************************************************/

/* ------------------------------------------------------------ */
/*				Include File Definitions						*/
/* ------------------------------------------------------------ */
#include "BT2.h"

/* ------------------------------------------------------------ */
/*					Definitions									*/
/* ------------------------------------------------------------ */
#define MAX_SIZE 125

/* ------------------------------------------------------------ */
/*        BT2::begin
**
**        Synopsis:
**				myBT.begin(Serial1, 9600);
**        Parameters:
**				- HardwareSerial &serialPort - The HardwareSerial port (Serial1, Serial2, etc) from
**											   MPIDE that will be used to communicate with the PmodBT2
**				- int baudRate - The baud rate to communicate to the PmodBTS with	
**		
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**			Initialize the system to communicate with the PmodBT2.
**
**
*/
void BT2::begin(HardwareSerial &serialPort, int baudRate)
{
	serialPort.begin(baudRate);
}

/* ------------------------------------------------------------ */
/*        BT2::send
**
**        Synopsis:
**				myBT.send(Serial1, 'a');
**        Parameters:
**				- HardwareSerial &serialPort - The HardwareSerial port (Serial1, Serial2, etc) from
**											   MPIDE that will be used to communicate with the PmodBT2
**				- char cha - A character to send through PmodBT2
**		
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**			Send a character through Bluetooth
**
**
*/
void BT2::send(HardwareSerial &serialPort, char cha)
{
	serialPort.print(cha);
	return;
}

/* ------------------------------------------------------------ */
/*        BT2::send
**
**        Synopsis:
**				myBT.send(Serial1, "Bluetooth is fun");
**        Parameters:
**				- HardwareSerial &serialPort - The HardwareSerial port (Serial1, Serial2, etc) from
**											   MPIDE that will be used to communicate with the PmodBT2
**				- char* str - An array of characters to send through PmodBT2
**		
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**			Send a string through Bluetooth
**
**
*/
void BT2::send(HardwareSerial &serialPort, char* str)
{
	int n = 0;
	while(str[n] != '\0') // '\0' marks the end of a string
	{
		serialPort.print(str[n]);
		n += 1;
	}
	serialPort.print("\n");
	return;
}

/* ------------------------------------------------------------ */
/*        BT2::read
**
**        Synopsis:
**				myBT.read(Serial1);
**        Parameters:
**				- HardwareSerial &serialPort - The HardwareSerial port (Serial1, Serial2, etc) from
**											   MPIDE that will be used to communicate with the PmodBT2
**		
**
**        Return Values:
**                char - character read through PmodBT2 
**
**        Errors:
**
**
**        Description:
**			Waits for PmodBT2 to send a non-NULL character and returns it.
**
**
*/
char BT2::read(HardwareSerial &serialPort)
{
	int ascii_num;
	ascii_num = serialPort.read(); //receive ascii value from PmodBT2
	while(ascii_num == -1) // wait until PmodBT2 sends real, non-NULL data
	{
		ascii_num = serialPort.read();
	}
	return (char)ascii_num; // convert ascii number to a character, then return it
}

/* ------------------------------------------------------------ */
/*        BT2::readSentence
**
**        Synopsis:
**				myBT.readSentence(Serial1);
**        Parameters:
**				- HardwareSerial &serialPort - The HardwareSerial port (Serial1, Serial2, etc) from
**											   MPIDE that will be used to communicate with the PmodBT2
**		
**
**        Return Values:
**                char* - A string ending in a carriage return read from BT2
**
**        Errors:
**
**
**        Description:
**			Waits for PmodBT2 to send a string of characters ending with carriage-return, and returns it
**
**
*/
char* BT2::readSentence(HardwareSerial &serialPort)
{
	char sentence[MAX_SIZE];
	int n = 0;
	sentence[n] = read(serialPort);
	while(sentence[n] != '\r' && n < MAX_SIZE - 1) // '\r' is a carriage return
	{
		n += 1;
		sentence[n] = read(serialPort);
	}
	return sentence;
}